==> cristalise-kernel-3.2-sources.jar: org/cristalise/kernel/persistency/TransactionalClusterStorage.java <==
/**
 * This file is part of the CRISTAL-iSE kernel.
 * Copyright (c) 2001-2015 The CRISTAL Consortium. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation; either version 3 of the License, or (at
 * your option) any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; with out even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public
 * License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
 *
 * http://www.fsf.org/licensing/licenses/lgpl.html
 */
package org.cristalise.kernel.persistency;

import org.cristalise.kernel.common.PersistencyException;
import org.cristalise.kernel.entity.C2KLocalObject;
import org.cristalise.kernel.lookup.ItemPath;

public abstract class TransactionalClusterStorage extends ClusterStorage {

	public abstract void begin(Object locker);

	public abstract void commit(Object locker) throws PersistencyException;
	
	public abstract void abort(Object locker);

	public abstract void put(ItemPath itemPath, C2KLocalObject obj, Object locker) throws PersistencyException;

	public abstract void delete(ItemPath itemPath, String path, Object locker) throws PersistencyException;

}

==> cristalise-kernel-4.5.0-sources.jar: org/cristalise/kernel/persistency/TransactionalClusterStorage.java <==
/**
 * This file is part of the CRISTAL-iSE kernel.
 * Copyright (c) 2001-2015 The CRISTAL Consortium. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation; either version 3 of the License, or (at
 * your option) any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; with out even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public
 * License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
 *
 * http://www.fsf.org/licensing/licenses/lgpl.html
 */
package org.cristalise.kernel.persistency;

import org.cristalise.kernel.common.PersistencyException;
import org.cristalise.kernel.entity.C2KLocalObject;
import org.cristalise.kernel.lookup.ItemPath;

public abstract class TransactionalClusterStorage extends ClusterStorage {

	public abstract void begin(Object locker) throws PersistencyException;

	public abstract void commit(Object locker) throws PersistencyException;
	
	public abstract void abort(Object locker) throws PersistencyException;

	public abstract void put(ItemPath itemPath, C2KLocalObject obj, Object locker) throws PersistencyException;

	public abstract void delete(ItemPath itemPath, String path, Object locker) throws PersistencyException;

}
